@@ -55,6 +55,34 @@ class PhRTPython3(PhRTBase):
         args.update(result if isinstance(result, dict) else {})
         result = exec_after(outputs=outputs, **args)
 
+        return result
+    except Exception as e:
+        logger = phs3logger(kwargs["job_id"])
+        logger.error(traceback.format_exc())
+        print(traceback.format_exc())
+        raise e
+        
+@click.command()
+@click.option('--owner')
+@click.option('--dag_name')
+@click.option('--run_id')
+@click.option('--job_full_name')
+@click.option('--job_id')
+@click.option('--job_args_name')
+def online_debug_execute(**kwargs):
+    try:
+        args = {"name": "$alfred_name"}
+        outputs = [$alfred_outputs]
+        
+        args.update(kwargs)
+        result = exec_before(**args)
+
+        args.update(result if isinstance(result, dict) else {})
+        result = execute(**args)
+
+        args.update(result if isinstance(result, dict) else {})
+        result = exec_after(outputs=outputs, **args)
+
         return result
     except Exception as e:
         logger = phs3logger(kwargs["job_id"])
@@ -291,7 +319,7 @@ class PhRTPython3(PhRTBase):
             result = {}
             for row in source:
                 if row and '=' in row:
-                    r = row.split('=')
+                    r = row.split('=', 1)
                     result[r[0].strip()] = eval(r[-1].strip())
             return result
 
